% Auto-generated chapter 75 for bukhari
% Hadiths in this chapter: 37

\hadithdefcmd{bukhari}{5640}{حَدَّثَنَا أَبُو الْيَمَانِ الْحَكَمُ بْنُ نَافِعٍ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ مُصِيبَةٍ تُصِيبُ الْمُسْلِمَ إِلاَّ كَفَّرَ اللَّهُ بِهَا عَنْهُ، حَتَّى الشَّوْكَةِ يُشَاكُهَا ‏"‏‏.‏\hadithno{5640}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) Allah's Messenger (ﷺ) said, "No calamity befalls a Muslim but that Allah expiates some of his sins because of it, even though it were the prick he receives from a thorn}}
\hadithdefcmd{bukhari}{5642}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عَمْرٍو، حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَلْحَلَةَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، وَعَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا يُصِيبُ الْمُسْلِمَ مِنْ نَصَبٍ وَلاَ وَصَبٍ وَلاَ هَمٍّ وَلاَ حُزْنٍ وَلاَ أَذًى وَلاَ غَمٍّ حَتَّى الشَّوْكَةِ يُشَاكُهَا، إِلاَّ كَفَّرَ اللَّهُ بِهَا مِنْ خَطَايَاهُ ‏"‏‏.‏\hadithno{5642}\hadithtrans{Narrated Abu Sa`id Al-Khudri and Abu Huraira:The Prophet (ﷺ) said, "No fatigue, nor disease, nor sorrow, nor sadness, nor hurt, nor distress befalls a Muslim, even if it were the prick he receives from a thorn, but that Allah expiates some of his sins for that}}
\hadithdefcmd{bukhari}{5643}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، عَنْ سَعْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ كَعْبٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ الْمُؤْمِنِ كَالْخَامَةِ مِنَ الزَّرْعِ تُفَيِّئُهَا الرِّيحُ مَرَّةً، وَتَعْدِلُهَا مَرَّةً، وَمَثَلُ الْمُنَافِقِ كَالأَرْزَةِ لاَ تَزَالُ حَتَّى يَكُونَ انْجِعَافُهَا مَرَّةً وَاحِدَةً ‏"‏‏.‏ وَقَالَ زَكَرِيَّاءُ حَدَّثَنِي سَعْدٌ، حَدَّثَنَا ابْنُ كَعْبٍ، عَنْ أَبِيهِ، كَعْبٍ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{5643}\hadithtrans{Narrated Ka`b:The Prophet (ﷺ) said, "The example of a believer is that of a fresh tender plant, which the wind bends lt sometimes and some other time it makes it straight. And the example of a hypocrite is that of a pine tree which keeps straight till once it is uprooted suddenly}}
\hadithdefcmd{bukhari}{5644}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ فُلَيْحٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ هِلاَلِ بْنِ عَلِيٍّ، مِنْ بَنِي عَامِرِ بْنِ لُؤَىٍّ عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلُ الْمُؤْمِنِ كَمَثَلِ الْخَامَةِ مِنَ الزَّرْعِ مِنْ حَيْثُ أَتَتْهَا الرِّيحُ كَفَأَتْهَا، فَإِذَا اعْتَدَلَتْ تَكَفَّأُ بِالْبَلاَءِ، وَالْفَاجِرُ كَالأَرْزَةِ صَمَّاءَ مُعْتَدِلَةً حَتَّى يَقْصِمَهَا اللَّهُ إِذَا شَاءَ ‏"‏‏.‏\hadithno{5644}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The example of a believer is that of a fresh tender plant; from whatever direction the wind comes, it bends it, but when the wind becomes quiet, it becomes straight again. Similarly, a believer is afflicted with calamities (but he remains patient till Allah removes his difficulties.) And an impious wicked person is like a pine tree which keeps hard and straight till Allah cuts (breaks) it down when He wishes." (See Hadith No. 558, Vol)}}
\hadithdefcmd{bukhari}{5645}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ، أَنَّهُ قَالَ سَمِعْتُ سَعِيدَ بْنَ يَسَارٍ أَبَا الْحُبَابِ، يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ يُرِدِ اللَّهُ بِهِ خَيْرًا يُصِبْ مِنْهُ ‏"‏‏.‏\hadithno{5645}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If Allah wants to do good to somebody, He afflicts him with trials}}
\hadithdefcmd{bukhari}{5646}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ،‏.‏ حَدَّثَنِي بِشْرُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَا رَأَيْتُ أَحَدًا أَشَدَّ عَلَيْهِ الْوَجَعُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{5646}\hadithtrans{Narrated Aisha:I never saw anybody suffering so much from sickness as Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{5647}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنِ الْحَارِثِ بْنِ سُوَيْدٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فِي مَرَضِهِ وَهْوَ يُوعَكُ وَعْكًا شَدِيدًا، وَقُلْتُ إِنَّكَ لَتُوعَكُ وَعْكًا شَدِيدًا‏.‏ قُلْتُ إِنَّ ذَاكَ بِأَنَّ لَكَ أَجْرَيْنِ‏.‏ قَالَ ‏ "‏ أَجَلْ مَا مِنْ مُسْلِمٍ يُصِيبُهُ أَذًى، إِلاَّ حَاتَّ اللَّهُ عَنْهُ خَطَايَاهُ، كَمَا تَحَاتُّ وَرَقُ الشَّجَرِ ‏"‏‏.‏\hadithno{5647}\hadithtrans{Narrated `Abdullah:I visited the Prophet (ﷺ) during his ailments and he was suffering from a high fever. I said, "You have a high fever. Is it because you will have a double reward for it?" He said, "Yes, for no Muslim is afflicted with any harm but that Allah will remove his sins as the leaves of a tree fall down}}
\hadithdefcmd{bukhari}{5648}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنِ الْحَارِثِ بْنِ سُوَيْدٍ، عَنْ عَبْدِ اللَّهِ، قَالَ دَخَلْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهْوَ يُوعَكُ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّكَ تُوعَكُ وَعْكًا شَدِيدًا‏.‏ قَالَ ‏"‏ أَجَلْ إِنِّي أُوعَكُ كَمَا يُوعَكُ رَجُلاَنِ مِنْكُمْ ‏"‏‏.‏ قُلْتُ ذَلِكَ أَنَّ لَكَ أَجْرَيْنِ قَالَ ‏"‏ أَجَلْ ذَلِكَ كَذَلِكَ، مَا مِنْ مُسْلِمٍ يُصِيبُهُ أَذًى شَوْكَةٌ فَمَا فَوْقَهَا، إِلاَّ كَفَّرَ اللَّهُ بِهَا سَيِّئَاتِهِ، كَمَا تَحُطُّ الشَّجَرَةُ وَرَقَهَا ‏"‏‏.‏\hadithno{5648}\hadithtrans{Narrated `Abdullah:I visited Allah's Messenger (ﷺ) while he was suffering from a high fever. I said, "O Allah's Messenger (ﷺ)! You have a high fever." He said, "Yes, I have as much fever as two men of you." I said, "Is it because you will have a double reward?" He said, "Yes, it is so. No Muslim is afflicted with any harm, even if it were the prick of a thorn, but that Allah expiates his sins because of that, as a tree sheds its leaves}}
\hadithdefcmd{bukhari}{5649}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَطْعِمُوا الْجَائِعَ، وَعُودُوا الْمَرِيضَ، وَفُكُّوا الْعَانِيَ ‏"‏‏.‏\hadithno{5649}\hadithtrans{Narrated Abu Muisa Al-Ash`ari:The Prophet (ﷺ) said, "Feed the hungry, visit the sick, and set free the captives}}
\hadithdefcmd{bukhari}{5650}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي أَشْعَثُ بْنُ سُلَيْمٍ، قَالَ سَمِعْتُ مُعَاوِيَةَ بْنَ سُوَيْدِ بْنِ مُقَرِّنٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ ـ رضى الله عنهما ـ قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِسَبْعٍ، وَنَهَانَا عَنْ سَبْعٍ، نَهَانَا عَنْ خَاتَمِ الذَّهَبِ، وَلُبْسِ الْحَرِيرِ، وَالدِّيبَاجِ، وَالإِسْتَبْرَقِ، وَعَنِ الْقَسِّيِّ، وَالْمِيثَرَةِ، وَأَمَرَنَا أَنْ نَتْبَعَ الْجَنَائِزَ، وَنَعُودَ الْمَرِيضَ، وَنُفْشِيَ السَّلاَمَ‏.‏\hadithno{5650}\hadithtrans{Narrated Al-Bara bin Azib:Allah's Messenger (ﷺ) ordered us to do seven things and forbade us to do seven other things. He forbade us to wear gold rings, silk, Dibaj, Istabriq, Qissy, and Maithara; and ordered us to accompany funeral processions, visit the sick and greet everybody. (See Hadith No)}}
\hadithdefcmd{bukhari}{5651}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ الْمُنْكَدِرِ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ يَقُولُ مَرِضْتُ مَرَضًا، فَأَتَانِي النَّبِيُّ صلى الله عليه وسلم يَعُودُنِي وَأَبُو بَكْرٍ وَهُمَا مَاشِيَانِ، فَوَجَدَانِي أُغْمِيَ عَلَىَّ، فَتَوَضَّأَ النَّبِيُّ صلى الله عليه وسلم ثُمَّ صَبَّ وَضُوءَهُ عَلَىَّ، فَأَفَقْتُ فَإِذَا النَّبِيُّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ كَيْفَ أَصْنَعُ فِي مَالِي كَيْفَ أَقْضِي فِي مَالِي فَلَمْ يُجِبْنِي بِشَىْءٍ حَتَّى نَزَلَتْ آيَةُ الْمِيرَاثِ‏.‏\hadithno{5651}\hadithtrans{Narrated Jabir bin `Abdullah:Once I fell ill. The Prophet (ﷺ) and Abu Bakr came walking to pay me a visit and found me unconscious. The Prophet (ﷺ) performed ablution and then poured the remaining water on me, and I came to my senses to see the Prophet. I said, "O Allah's Messenger (ﷺ)! What shall I do with my property? How shall I dispose of (distribute) my property?" He did not reply till the Verse of inheritance was revealed}}
\hadithdefcmd{bukhari}{5652}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عِمْرَانَ أَبِي بَكْرٍ، قَالَ حَدَّثَنِي عَطَاءُ بْنُ أَبِي رَبَاحٍ، قَالَ قَالَ لِي ابْنُ عَبَّاسٍ أَلاَ أُرِيكَ امْرَأَةً مِنْ أَهْلِ الْجَنَّةِ قُلْتُ بَلَى‏.‏ قَالَ هَذِهِ الْمَرْأَةُ السَّوْدَاءُ أَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ إِنِّي أُصْرَعُ، وَإِنِّي أَتَكَشَّفُ فَادْعُ اللَّهَ لِي‏.‏ قَالَ ‏ "‏ إِنْ شِئْتِ صَبَرْتِ وَلَكِ الْجَنَّةُ وَإِنْ شِئْتِ دَعَوْتُ اللَّهَ أَنْ يُعَافِيَكِ ‏"‏‏.‏ فَقَالَتْ أَصْبِرُ‏.‏ فَقَالَتْ إِنِّي أَتَكَشَّفُ فَادْعُ اللَّهَ أَنْ لاَ أَتَكَشَّفَ، فَدَعَا لَهَا‏.‏ حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا مَخْلَدٌ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، أَنَّهُ رَأَى أُمَّ زُفَرَ تِلْكَ، امْرَأَةٌ طَوِيلَةٌ سَوْدَاءُ عَلَى سِتْرِ الْكَعْبَةِ‏.‏\hadithno{5652}\hadithtrans{Narrated 'Ata bin Abi Rabah:Ibn `Abbas said to me, "Shall I show you a woman of the people of Paradise?" I said, "Yes." He said, "This black lady came to the Prophet (ﷺ) and said, 'I get attacks of epilepsy and my body becomes uncovered; please invoke Allah for me.' The Prophet (ﷺ) said (to her), 'If you wish, be patient and you will have (enter) Paradise; and if you wish, I will invoke Allah to cure you.' She said, 'I will remain patient,' and added, 'but I become uncovered, so please invoke Allah for me that I may not become uncovered.' So he invoked Allah for her." Narrated 'Ata: That he had seen Um Zafar, the tall black lady, at (holding) the curtain of the Ka`ba}}
\hadithdefcmd{bukhari}{5653}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي ابْنُ الْهَادِ، عَنْ عَمْرٍو، مَوْلَى الْمُطَّلِبِ عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ قَالَ إِذَا ابْتَلَيْتُ عَبْدِي بِحَبِيبَتَيْهِ فَصَبَرَ عَوَّضْتُهُ مِنْهُمَا الْجَنَّةَ ‏"‏‏.‏ يُرِيدُ عَيْنَيْهِ‏.‏ تَابَعَهُ أَشْعَثُ بْنُ جَابِرٍ وَأَبُو ظِلاَلٍ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{5653}\hadithtrans{Narrated Anas bin Malik:I heard Allah's Messenger (ﷺ) saying, "Allah said, 'If I deprive my slave of his two beloved things (i.e., his eyes) and he remains patient, I will let him enter Paradise in compensation for them}}
\hadithdefcmd{bukhari}{5654}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ وُعِكَ أَبُو بَكْرٍ وَبِلاَلٌ ـ رضى الله عنهما ـ قَالَتْ فَدَخَلْتُ عَلَيْهِمَا قُلْتُ يَا أَبَتِ كَيْفَ تَجِدُكَ وَيَا بِلاَلُ كَيْفَ تَجِدُكَ قَالَتْ وَكَانَ أَبُو بَكْرٍ إِذَا أَخَذَتْهُ الْحُمَّى يَقُولُ كُلُّ امْرِئٍ مُصَبَّحٌ فِي أَهْلِهِ وَالْمَوْتُ أَدْنَى مِنْ شِرَاكِ نَعْلِهِ وَكَانَ بِلاَلٌ إِذَا أَقْلَعَتْ عَنْهُ يَقُولُ أَلاَ لَيْتَ شِعْرِي هَلْ أَبِيتَنَّ لَيْلَةً بَوَادٍ وَحَوْلِي إِذْخِرٌ وَجَلِيلُ وَهَلْ أَرِدَنْ يَوْمًا مِيَاهَ مِجَنَّةٍ وَهَلْ تَبْدُوَنْ لِي شَامَةٌ وَطَفِيلُ قَالَتْ عَائِشَةُ فَجِئْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَقَالَ ‏ "‏ اللَّهُمَّ حَبِّبْ إِلَيْنَا الْمَدِينَةَ كَحُبِّنَا مَكَّةَ أَوْ أَشَدَّ، اللَّهُمَّ وَصَحِّحْهَا، وَبَارِكْ لَنَا فِي مُدِّهَا وَصَاعِهَا، وَانْقُلْ حُمَّاهَا فَاجْعَلْهَا بِالْجُحْفَةِ ‏"‏‏.‏\hadithno{5654}\hadithtrans{Narrated `Aisha:When Allah's Messenger (ﷺ) emigrated to Medina, Abu Bakr and Bilal got a fever. I entered upon them and asked, "O my father! How are you? O Bilal! How are you?" Whenever fever attacked Abu Bakr, he would recite the following poetic verses: 'Everybody is staying alive among his people, yet death is nearer to him than his shoe laces." And whenever the fever deserted Bilal, he would recite (two poetic lines): 'Would that I could stay overnight in a valley wherein I would be surrounded by Idhkhir and Jalil (two kinds of good smelling grass). Would that one day I would drink of the water of Majinna and would that Shama and Tafil (two mountains at Mecca) would appear to me.' Then I came and informed Allah's Messenger (ﷺ) about that, whereupon he said, "O Allah! Make us love Medina as much or more than we love Mecca. O Allah! Make it healthy and bless its Mudd and Sa for us, and take away its fever and put it in Al Juhfa}}
\hadithdefcmd{bukhari}{5655}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَاصِمٌ، قَالَ سَمِعْتُ أَبَا عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ ـ رضى الله عنهما ـ أَنَّ ابْنَةً لِلنَّبِيِّ، صلى الله عليه وسلم أَرْسَلَتْ إِلَيْهِ وَهْوَ مَعَ النَّبِيِّ صلى الله عليه وسلم وَسَعْدٍ وَأُبَىٍّ نَحْسِبُ أَنَّ ابْنَتِي قَدْ حُضِرَتْ فَاشْهَدْنَا فَأَرْسَلَ إِلَيْهَا السَّلاَمَ وَيَقُولُ ‏"‏ إِنَّ لِلَّهِ مَا أَخَذَ وَمَا أَعْطَى وَكُلُّ شَىْءٍ عِنْدَهُ مُسَمًّى فَلْتَحْتَسِبْ وَلْتَصْبِرْ ‏"‏‏.‏ فَأَرْسَلَتْ تُقْسِمُ عَلَيْهِ، فَقَامَ النَّبِيُّ صلى الله عليه وسلم وَقُمْنَا، فَرُفِعَ الصَّبِيُّ فِي حَجْرِ النَّبِيِّ صلى الله عليه وسلم وَنَفْسُهُ تَقَعْقَعُ فَفَاضَتْ عَيْنَا النَّبِيِّ صلى الله عليه وسلم فَقَالَ لَهُ سَعْدٌ مَا هَذَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ هَذِهِ رَحْمَةٌ وَضَعَهَا اللَّهُ فِي قُلُوبِ مَنْ شَاءَ مِنْ عِبَادِهِ، وَلاَ يَرْحَمُ اللَّهُ مِنْ عِبَادِهِ إِلاَّ الرُّحَمَاءَ ‏"‏‏.‏\hadithno{5655}\hadithtrans{Narrated Abu `Uthman:Usama bin Zaid said that while he. Sa`d and Ubai bin Ka`b were with the Prophet (ﷺ) a daughter of the Prophet sent a message to him, saying. 'My daughter is dying; please come to us." The Prophet (ﷺ) sent her his greetings and added "It is for Allah what He takes, and what He gives; and everything before His sight has a limited period. So she should hope for Allah's reward and remain patient." She again sent a message, beseeching him by Allah, to come. So the Prophet (ﷺ) got up. and so did we (and went there). The child was placed on his lap while his breath was irregular. Tears flowed from the eyes of the Prophet. Sa`d said to him, "What is this, O Allah's Messenger (ﷺ)?" He said. "This Is Mercy which Allah has embedded in the hearts of whomever He wished of His slaves. And Allah does not bestow His Mercy, except on the merciful among His slaves. (See Hadith No. 373 Vol)}}
\hadithdefcmd{bukhari}{5656}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُخْتَارٍ، حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَلَى أَعْرَابِيٍّ يَعُودُهُ ـ قَالَ ـ وَكَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا دَخَلَ عَلَى مَرِيضٍ يَعُودُهُ فَقَالَ لَهُ ‏"‏ لاَ بَأْسَ طَهُورٌ إِنْ شَاءَ اللَّهُ ‏"‏‏.‏ قَالَ قُلْتَ طَهُورٌ، كَلاَّ بَلْ هِيَ حُمَّى تَفُورُ ـ أَوْ تَثُورُ ـ عَلَى شَيْخٍ كَبِيرٍ، تُزِيرُهُ الْقُبُورَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَنَعَمْ إِذًا ‏"‏‏.‏\hadithno{5656}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) went to visit a sick bedouin. Whenever the Prophet (ﷺ) went to a patient, he used to say to him, "Don't worry, if Allah will, it will be expiation (for your sins):" The bedouin said, "You say expiation? No, it is but a fever that is boiling or harassing an old man and will lead him to his grave without his will." The Prophet (ﷺ) said, "Then, yes, it is so}}
\hadithdefcmd{bukhari}{5657}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ غُلاَمًا، لِيَهُودَ كَانَ يَخْدُمُ النَّبِيَّ صلى الله عليه وسلم فَمَرِضَ‏.‏ فَأَتَاهُ النَّبِيُّ صلى الله عليه وسلم يَعُودُهُ فَقَالَ ‏ "‏ أَسْلِمْ ‏"‏‏.‏ فَأَسْلَمَ‏.‏ وَقَالَ سَعِيدُ بْنُ الْمُسَيَّبِ عَنْ أَبِيهِ، لَمَّا حُضِرَ أَبُو طَالِبٍ جَاءَهُ النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{5657}\hadithtrans{Narrated Anas:A Jewish boy used to serve the Prophet (ﷺ) and became ill. The Prophet (ﷺ) went to pay him a visit and said to him, "Embrace Islam," and he did embrace Islam. Al-Musaiyab said: When Abu Talib was on his deathbed, the Prophet (ﷺ) visited him}}
\hadithdefcmd{bukhari}{5658}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، حَدَّثَنَا هِشَامٌ، قَالَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَلَيْهِ نَاسٌ يَعُودُونَهُ فِي مَرَضِهِ فَصَلَّى بِهِمْ جَالِسًا فَجَعَلُوا يُصَلُّونَ قِيَامًا، فَأَشَارَ إِلَيْهِمِ اجْلِسُوا، فَلَمَّا فَرَغَ قَالَ ‏ "‏ إِنَّ الإِمَامَ لَيُؤْتَمُّ بِهِ، فَإِذَا رَكَعَ فَارْكَعُوا وَإِذَا رَفَعَ فَارْفَعُوا، وَإِنْ صَلَّى جَالِسًا فَصَلُّوا جُلُوسًا ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ قَالَ الْحُمَيْدِيُّ هَذَا الْحَدِيثُ مَنْسُوخٌ لأَنَّ النَّبِيَّ صلى الله عليه وسلم آخِرَ مَا صَلَّى صَلَّى قَاعِدًا وَالنَّاسُ خَلْفَهُ قِيَامٌ‏.‏\hadithno{5658}\hadithtrans{Narrated `Aisha:During the ailment of the Prophet (ﷺ) some people came to visits him. He led them in prayer while sitting. but they prayed standing, so he waved to them to sit down. When he had finished the prayer, he said, "An Imam is to be followed, so when he bows, you should bow. and when he raises his head, you should raise yours, and if he prays sitting. you should pray sitting." Abu `Abdullah said Al-Humaidi said, (The order of ) "This narration has been abrogated by the last action of the Prophet (ﷺ) as he led the prayer sitting, while the people prayed standing behind him}}
\hadithdefcmd{bukhari}{5659}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الْجُعَيْدُ، عَنْ عَائِشَةَ بِنْتِ سَعْدٍ، أَنَّ أَبَاهَا، قَالَ تَشَكَّيْتُ بِمَكَّةَ شَكْوًا شَدِيدًا، فَجَاءَنِي النَّبِيُّ صلى الله عليه وسلم يَعُودُنِي، فَقُلْتُ يَا نَبِيَّ اللَّهِ إِنِّي أَتْرُكُ مَالاً وَإِنِّي لَمْ أَتْرُكْ إِلاَّ ابْنَةً وَاحِدَةً، فَأُوصِي بِثُلُثَىْ مَالِي وَأَتْرُكُ الثُّلُثَ فَقَالَ ‏"‏ لاَ ‏"‏‏.‏ قُلْتُ فَأُوصِي بِالنِّصْفِ وَأَتْرُكُ النِّصْفَ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قُلْتُ فَأُوصِي بِالثُّلُثِ وَأَتْرُكُ لَهَا الثُّلُثَيْنِ قَالَ ‏"‏ الثُّلُثُ وَالثُّلُثُ كَثِيرٌ ‏"‏‏.‏ ثُمَّ وَضَعَ يَدَهُ عَلَى جَبْهَتِهِ، ثُمَّ مَسَحَ يَدَهُ عَلَى وَجْهِي وَبَطْنِي ثُمَّ قَالَ ‏"‏ اللَّهُمَّ اشْفِ سَعْدًا وَأَتْمِمْ لَهُ هِجْرَتَهُ ‏"‏‏.‏ فَمَا زِلْتُ أَجِدُ بَرْدَهُ عَلَى كَبِدِي فِيمَا يُخَالُ إِلَىَّ حَتَّى السَّاعَةِ‏.‏\hadithno{5659}\hadithtrans{Narrated Sa`d:I became seriously ill at Mecca and the Prophet (ﷺ) came to visit me. I said, "O Allah's Messenger (ﷺ)! I shall leave behind me a good fortune, but my heir is my only daughter; shall I bequeath two third of my property to be spent in charity and leave one third (for my heir)?" He said, "No." I said, "Shall I bequeath half and leave half?" He said, "No." I said, "Shall I bequeath one third and leave two thirds?" He said, "One third is alright, though even one third is too much." Then he placed his hand on his forehead and passed it over my face and `Abdomen and said, "O Allah! Cure Sa`d and complete his emigration." I feel as if I have been feeling the coldness of his hand on my liver ever since}}
\hadithdefcmd{bukhari}{5660}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنِ الْحَارِثِ بْنِ سُوَيْدٍ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ دَخَلْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهْوَ يُوعَكُ فَمَسِسْتُهُ بِيَدِي فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّكَ تُوعَكُ وَعْكًا شَدِيدًا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَجَلْ إِنِّي أُوعَكُ كَمَا يُوعَكُ رَجُلاَنِ مِنْكُمْ ‏"‏‏.‏ فَقُلْتُ ذَلِكَ أَنَّ لَكَ أَجْرَيْنِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَجَلْ ‏"‏‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ مُسْلِمٍ يُصِيبُهُ أَذًى مَرَضٌ فَمَا سِوَاهُ إِلاَّ حَطَّ اللَّهُ لَهُ سَيِّئَاتِهِ كَمَا تَحُطُّ الشَّجَرَةُ وَرَقَهَا ‏"‏‏.‏\hadithno{5660}\hadithtrans{Narrated `Abdullah bin Mas`ud:I visited Allah's Messenger (ﷺ) while he was suffering from a high fever. I touched him with my hand and said, "O Allah's Messenger (ﷺ)! You have a high fever." Allah's Messenger (ﷺ) said, "Yes, I have as much fever as two men of you have." I said, "Is it because you will get a double reward?" Allah's Messenger (ﷺ) said, "Yes, no Muslim is afflicted with harm because of sickness or some other inconvenience, but that Allah will remove his sins for him as a tree sheds its leaves}}
\hadithdefcmd{bukhari}{5661}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنِ الْحَارِثِ بْنِ سُوَيْدٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فِي مَرَضِهِ فَمَسِسْتُهُ وَهْوَ يُوعَكُ وَعْكًا شَدِيدًا فَقُلْتُ إِنَّكَ لَتُوعَكُ وَعْكًا شَدِيدًا، وَذَلِكَ أَنَّ لَكَ أَجْرَيْنِ‏.‏ قَالَ ‏ "‏ أَجَلْ، وَمَا مِنْ مُسْلِمٍ يُصِيبُهُ أَذًى إِلاَّ حَاتَّتْ عَنْهُ خَطَايَاهُ كَمَا تَحَاتُّ وَرَقُ الشَّجَرِ ‏"‏‏.‏\hadithno{5661}\hadithtrans{Narrated `Abdullah:I visited the Prophet (ﷺ) during his illness and touched him while he was having a fever. I said to him, "You have a high fever; is it because you will get a double reward?" He said, "Yes. No Muslim is afflicted with any harm, but that his sins will be annulled as the leave of a tree fall down}}
\hadithdefcmd{bukhari}{5662}{حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ خَالِدٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ عَلَى رَجُلٍ يَعُودُهُ فَقَالَ ‏"‏ لاَ بَأْسَ طَهُورٌ إِنْ شَاءَ اللَّهُ ‏"‏‏.‏ فَقَالَ كَلاَّ بَلْ حُمَّى تَفُورُ عَلَى شَيْخٍ كَبِيرٍ كَيْمَا تُزِيرَهُ الْقُبُورَ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَنَعَمْ إِذًا ‏"‏‏.‏\hadithno{5662}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) entered upon sick man to pay him a visit, and said to him, "Don't worry, Allah willing, (your sickness will be) an expiation for your sins." The man said, "No, it is but a fever that is boiling within an old man and will send him to his grave." On that, the Prophet (ﷺ) said, "Then yes, it is so}}
\hadithdefcmd{bukhari}{5663}{حَدَّثَنِي يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ أُسَامَةَ بْنَ زَيْدٍ، أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم رَكِبَ عَلَى حِمَارٍ عَلَى إِكَافٍ عَلَى قَطِيفَةٍ فَدَكِيَّةٍ، وَأَرْدَفَ أُسَامَةَ وَرَاءَهُ يَعُودُ سَعْدَ بْنَ عُبَادَةَ قَبْلَ وَقْعَةِ بَدْرٍ فَسَارَ حَتَّى مَرَّ بِمَجْلِسٍ فِيهِ عَبْدُ اللَّهِ بْنُ أُبَىٍّ ابْنُ سَلُولَ وَذَلِكَ قَبْلَ أَنْ يُسْلِمَ عَبْدُ اللَّهِ، وَفِي الْمَجْلِسِ أَخْلاَطٌ مِنَ الْمُسْلِمِينَ وَالْمُشْرِكِينَ عَبَدَةِ الأَوْثَانِ وَالْيَهُودِ، وَفِي الْمَجْلِسِ عَبْدُ اللَّهِ بْنُ رَوَاحَةَ، فَلَمَّا غَشِيَتِ الْمَجْلِسَ عَجَاجَةُ الدَّابَّةِ خَمَّرَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ أَنْفَهُ بِرِدَائِهِ، قَالَ لاَ تُغَيِّرُوا عَلَيْنَا فَسَلَّمَ النَّبِيُّ صلى الله عليه وسلم وَوَقَفَ وَنَزَلَ فَدَعَاهُمْ إِلَى اللَّهِ فَقَرَأَ عَلَيْهِمُ الْقُرْآنَ، فَقَالَ لَهُ عَبْدُ اللَّهِ بْنُ أُبَىٍّ يَا أَيُّهَا الْمَرْءُ إِنَّهُ لاَ أَحْسَنَ مِمَّا تَقُولُ إِنْ كَانَ حَقًّا، فَلاَ تُؤْذِنَا بِهِ فِي مَجْلِسِنَا، وَارْجِعْ إِلَى رَحْلِكَ فَمَنْ جَاءَكَ فَاقْصُصْ عَلَيْهِ‏.‏ قَالَ ابْنُ رَوَاحَةَ بَلَى يَا رَسُولَ اللَّهِ فَاغْشَنَا بِهِ فِي مَجَالِسِنَا فَإِنَّا نُحِبُّ ذَلِكَ فَاسْتَبَّ الْمُسْلِمُونَ وَالْمُشْرِكُونَ وَالْيَهُودُ حَتَّى كَادُوا يَتَثَاوَرُونَ فَلَمْ يَزَلِ النَّبِيُّ صلى الله عليه وسلم حَتَّى سَكَتُوا فَرَكِبَ النَّبِيُّ صلى الله عليه وسلم دَابَّتَهُ حَتَّى دَخَلَ عَلَى سَعْدِ بْنِ عُبَادَةَ فَقَالَ لَهُ ‏ "‏ أَىْ سَعْدُ أَلَمْ تَسْمَعْ مَا قَالَ أَبُو حُبَابٍ ‏"‏‏.‏ يُرِيدُ عَبْدَ اللَّهِ بْنَ أُبَىٍّ‏.‏ قَالَ سَعْدٌ يَا رَسُولَ اللَّهِ اعْفُ عَنْهُ وَاصْفَحْ فَلَقَدْ أَعْطَاكَ اللَّهُ مَا أَعْطَاكَ وَلَقَدِ اجْتَمَعَ أَهْلُ هَذِهِ الْبَحْرَةِ أَنْ يُتَوِّجُوهُ فَيُعَصِّبُوهُ فَلَمَّا رَدَّ ذَلِكَ بِالْحَقِّ الَّذِي أَعْطَاكَ شَرِقَ بِذَلِكَ، فَذَلِكَ الَّذِي فَعَلَ بِهِ مَا رَأَيْتَ‏.‏\hadithno{5663}\hadithtrans{Narrated Usama bin Zaid:The Prophet (ﷺ) rode a donkey having a saddle with a Fadakiyya velvet covering. He mounted me behind him and went to visit Sa`d bin 'Ubada, and that had been before the battle of Badr. The Prophet (ﷺ) proceeded till he passed by a gathering in which `Abdullah bin Ubai bin Salul was present, and that had been before `Abdullah embraced Islam. The gathering comprised of Muslims, polytheists, i.e., isolators and Jews. `Abdullah bin Rawaha was also present in that gathering. When dust raised by the donkey covered the gathering, `Abdullah bin Ubai covered his nose with his upper garment and said, "Do not trouble us with dust." The Prophet (ﷺ) greeted them, stopped and dismounted. Then he invited them to Allah (i.e., to embrace Islam) and recited to them some verses of the Holy Qur'an. On that, `Abdullah bin Ubai said, "O man ! There is nothing better than what you say if it is true. Do not trouble us with it in our gathering, but return to your house, and if somebody comes to you, teach him there." On that `Abdullah bin Rawaha said, Yes, O Allah's Messenger (ﷺ)! Bring your teachings to our gathering, for we love that." So the Muslims, the pagans and the Jews started abusing each other till they were about to fight. The Prophet (ﷺ) kept on quietening them till they became calm. Thereupon the Prophet mounted his animal and proceeded till he entered upon Sa`d bin Ubada. He said to him "O Sa`d! Have you not heard what Abu Hubab (i.e., `Abdullah bin Ubai) said?" Sa`d said, 'O Allah's Apostle! Excuse and forgive him, for Allah has given you what He has given you. The people of this town (Medina decided unanimously to crown him and make him their chief by placing a turban on his head, but when that was prevented by the Truth which Allah had given you he (`Abdullah bin Ubai) was grieved out of jealously, and that was the reason which caused him to behave in the way you have seen}}
\hadithdefcmd{bukhari}{5664}{حَدَّثَنَا عَمْرُو بْنُ عَبَّاسٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدٍ ـ هُوَ ابْنُ الْمُنْكَدِرِ ـ عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ جَاءَنِي النَّبِيُّ صلى الله عليه وسلم يَعُودُنِي لَيْسَ بِرَاكِبِ بَغْلٍ وَلاَ بِرْذَوْنٍ‏.‏\hadithno{5664}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) came to visit me (while I was sick) and he was riding neither a mule, nor a horse}}
\hadithdefcmd{bukhari}{5665}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، وَأَيُّوبَ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ ـ رضى الله عنه‏.‏ مَرَّ بِيَ النَّبِيُّ صلى الله عليه وسلم وَأَنَا أُوقِدُ تَحْتَ الْقِدْرِ فَقَالَ ‏ "‏ أَيُؤْذِيكَ هَوَامُّ رَأْسِكَ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ فَدَعَا الْحَلاَّقَ فَحَلَقَهُ ثُمَّ أَمَرَنِي بِالْفِدَاءِ‏.‏\hadithno{5665}\hadithtrans{Narrated Ka`b bin 'Ujara:The Prophet (ﷺ) passed by me while I was kindling a fire under a (cooking) pot. He said, "Do the lice of your head trouble you?" I said, "Yes." So he called a barber to shave my head and ordered me to make expiation for that}}
\hadithdefcmd{bukhari}{5666}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى أَبُو زَكَرِيَّاءَ، أَخْبَرَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ سَمِعْتُ الْقَاسِمَ بْنَ مُحَمَّدٍ، قَالَ قَالَتْ عَائِشَةُ وَارَأْسَاهْ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ذَاكِ لَوْ كَانَ وَأَنَا حَىٌّ، فَأَسْتَغْفِرُ لَكِ وَأَدْعُو لَكِ ‏"‏‏.‏ فَقَالَتْ عَائِشَةُ وَاثُكْلِيَاهْ، وَاللَّهِ إِنِّي لأَظُنُّكَ تُحِبُّ مَوْتِي، وَلَوْ كَانَ ذَاكَ لَظَلِلْتَ آخِرَ يَوْمِكَ مُعَرِّسًا بِبَعْضِ أَزْوَاجِكَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بَلْ أَنَا وَارَأْسَاهْ لَقَدْ هَمَمْتُ أَوْ أَرَدْتُ أَنْ أُرْسِلَ إِلَى أَبِي بَكْرٍ وَابْنِهِ، وَأَعْهَدَ أَنْ يَقُولَ الْقَائِلُونَ أَوْ يَتَمَنَّى الْمُتَمَنُّونَ، ثُمَّ قُلْتُ يَأْبَى اللَّهُ وَيَدْفَعُ الْمُؤْمِنُونَ، أَوْ يَدْفَعُ اللَّهُ وَيَأْبَى الْمُؤْمِنُونَ ‏"‏‏.‏\hadithno{5666}\hadithtrans{Narrated Al-Qasim bin Muhammad:`Aisha, (complaining of headache) said, "Oh, my head"! Allah's Messenger (ﷺ) said, "I wish that had happened while I was still living, for then I would ask Allah's Forgiveness for you and invoke Allah for you." Aisha said, "Wa thuklayah! By Allah, I think you want me to die; and If this should happen, you would spend the last part of the day sleeping with one of your wives!" The Prophet (ﷺ) said, "Nay, I should say, 'Oh my head!' I felt like sending for Abu Bakr and his son, and appoint him as my successor lest some people claimed something or some others wished something, but then I said (to myself), 'Allah would not allow it to be otherwise, and the Muslims would prevent it to be otherwise}}
\hadithdefcmd{bukhari}{5667}{حَدَّثَنَا مُوسَى، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُسْلِمٍ، حَدَّثَنَا سُلَيْمَانُ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنِ الْحَارِثِ بْنِ سُوَيْدٍ، عَنِ ابْنِ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ دَخَلْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم وَهْوَ يُوعَكُ فَمَسِسْتُهُ فَقُلْتُ إِنَّكَ لَتُوعَكُ وَعْكًا شَدِيدًا‏.‏ قَالَ ‏"‏ أَجَلْ كَمَا يُوعَكُ رَجُلاَنِ مِنْكُمْ ‏"‏‏.‏ قَالَ لَكَ أَجْرَانِ قَالَ ‏"‏ نَعَمْ مَا مِنْ مُسْلِمٍ يُصِيبُهُ أَذًى مَرَضٌ فَمَا سِوَاهُ إِلاَّ حَطَّ اللَّهُ سَيِّئَاتِهِ كَمَا تَحُطُّ الشَّجَرَةُ وَرَقَهَا ‏"‏‏.‏\hadithno{5667}\hadithtrans{Narrated Ibn Mas`ud:I visited the Prophet (ﷺ) while he was having a high fever. I touched him an said, "You have a very high fever" He said, "Yes, as much fever as two me of you may have." I said. "you will have a double reward?" He said, "Yes No Muslim is afflicted with hurt caused by disease or some other inconvenience, but that Allah will remove his sins as a tree sheds its leaves}}
\hadithdefcmd{bukhari}{5668}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي سَلَمَةَ، أَخْبَرَنَا الزُّهْرِيُّ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ جَاءَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَعُودُنِي مِنْ وَجَعٍ اشْتَدَّ بِي زَمَنَ حَجَّةِ الْوَدَاعِ فَقُلْتُ بَلَغَ بِي مَا تَرَى وَأَنَا ذُو مَالٍ وَلاَ يَرِثُنِي إِلاَّ ابْنَةٌ لِي أَفَأَتَصَدَّقُ بِثُلُثَىْ مَالِي قَالَ ‏"‏ لاَ ‏"‏‏.‏ قُلْتُ بِالشَّطْرِ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قُلْتُ الثُّلُثُ قَالَ ‏"‏ الثُّلُثُ كَثِيرٌ، أَنْ تَدَعَ وَرَثَتَكَ أَغْنِيَاءَ خَيْرٌ مِنْ أَنْ تَذَرَهُمْ عَالَةً يَتَكَفَّفُونَ النَّاسَ وَلَنْ تُنْفِقَ نَفَقَةً تَبْتَغِي بِهَا وَجْهَ اللَّهِ إِلاَّ أُجِرْتَ عَلَيْهَا حَتَّى مَا تَجْعَلُ فِي فِي امْرَأَتِكَ ‏"‏‏.‏\hadithno{5668}\hadithtrans{Narrated Sa`d:Allah's Messenger (ﷺ) came to visit me during my ailment which had been aggravated during Hajjat-al- Wada`. I said to him, "You see how sick I am. I have much property but have no heir except my only daughter May I give two thirds of my property in charity?"! He said, "No." I said, "Half of it?" He said, "No." I said "One third?" He said, "One third is too much, for to leave your heirs rich is better than to leave them poor, begging of others. Nothing you spend seeking Allah's pleasure but you shall get a reward for it, even for what you put in the mouth of your wife}}
\hadithdefcmd{bukhari}{5669}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، حَدَّثَنَا هِشَامٌ، عَنْ مَعْمَرٍ، وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَمَّا حُضِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَفِي الْبَيْتِ رِجَالٌ فِيهِمْ عُمَرُ بْنُ الْخَطَّابِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلُمَّ أَكْتُبْ لَكُمْ كِتَابًا لاَ تَضِلُّوا بَعْدَهُ ‏"‏‏.‏ فَقَالَ عُمَرُ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَدْ غَلَبَ عَلَيْهِ الْوَجَعُ وَعِنْدَكُمُ الْقُرْآنُ، حَسْبُنَا كِتَابُ اللَّهِ فَاخْتَلَفَ أَهْلُ الْبَيْتِ فَاخْتَصَمُوا، مِنْهُمْ مَنْ يَقُولُ قَرِّبُوا يَكْتُبْ لَكُمُ النَّبِيُّ صلى الله عليه وسلم كِتَابًا لَنْ تَضِلُّوا بَعْدَهُ، وَمِنْهُمْ مَنْ يَقُولُ مَا قَالَ عُمَرُ فَلَمَّا أَكْثَرُوا اللَّغْوَ وَالاِخْتِلاَفَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قُومُوا ‏"‏‏.‏ قَالَ عُبَيْدُ اللَّهِ فَكَانَ ابْنُ عَبَّاسٍ يَقُولُ إِنَّ الرَّزِيَّةَ كُلَّ الرَّزِيَّةِ مَا حَالَ بَيْنَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَبَيْنَ أَنْ يَكْتُبَ لَهُمْ ذَلِكَ الْكِتَابَ مِنِ اخْتِلاَفِهِمْ وَلَغَطِهِمْ‏.‏\hadithno{5669}\hadithtrans{Narrated Ibn `Abbas:When Allah's Messenger (ﷺ) was on his death-bed and in the house there were some people among whom was `Umar bin Al-Khattab, the Prophet (ﷺ) said, "Come, let me write for you a statement after which you will not go astray." `Umar said, "The Prophet (ﷺ) is seriously ill and you have the Qur'an; so the Book of Allah is enough for us." The people present in the house differed and quarrelled. Some said "Go near so that the Prophet (ﷺ) may write for you a statement after which you will not go astray," while the others said as `Umar said. When they caused a hue and cry before the Prophet, Allah's Messenger (ﷺ) said, "Go away!" Narrated 'Ubaidullah: Ibn `Abbas used to say, "It was very unfortunate that Allah's Messenger (ﷺ) was prevented from writing that statement for them because of their disagreement and noise}}
\hadithdefcmd{bukhari}{5670}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَمْزَةَ، حَدَّثَنَا حَاتِمٌ ـ هُوَ ابْنُ إِسْمَاعِيلَ ـ عَنِ الْجُعَيْدِ، قَالَ سَمِعْتُ السَّائِبَ، يَقُولُ ذَهَبَتْ بِي خَالَتِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ ابْنَ أُخْتِي وَجِعٌ فَمَسَحَ رَأْسِي وَدَعَا لِي بِالْبَرَكَةِ، ثُمَّ تَوَضَّأَ فَشَرِبْتُ مِنْ وَضُوئِهِ وَقُمْتُ خَلْفَ ظَهْرِهِ فَنَظَرْتُ إِلَى خَاتَمِ النُّبُوَّةِ بَيْنَ كَتِفَيْهِ مِثْلَ زِرِّ الْحَجَلَةِ‏.‏\hadithno{5670}\hadithtrans{Narrated As-Sa'ib:My aunt took me to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! My nephew is- ill." The Prophet (ﷺ) touched my head with his hand and invoked Allah to bless me. He then performed ablution and I drank of the remaining water of his ablution and then stood behind his back and saw "Khatam An- Nubuwwa" (The Seal of Prophethood) between his shoulders like a button of a tent}}
\hadithdefcmd{bukhari}{5671}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ يَتَمَنَّيَنَّ أَحَدُكُمُ الْمَوْتَ مِنْ ضُرٍّ أَصَابَهُ، فَإِنْ كَانَ لاَ بُدَّ فَاعِلاً فَلْيَقُلِ اللَّهُمَّ أَحْيِنِي مَا كَانَتِ الْحَيَاةُ خَيْرًا لِي، وَتَوَفَّنِي إِذَا كَانَتِ الْوَفَاةُ خَيْرًا لِي ‏"‏‏.‏\hadithno{5671}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "None of you should wish for death because of a calamity befalling him; but if he has to wish for death, he should say: "O Allah! Keep me alive as long as life is better for me, and let me die if death is better for me}}
\hadithdefcmd{bukhari}{5672}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، قَالَ دَخَلْنَا عَلَى خَبَّابٍ نَعُودُهُ وَقَدِ اكْتَوَى سَبْعَ كَيَّاتٍ فَقَالَ إِنَّ أَصْحَابَنَا الَّذِينَ سَلَفُوا مَضَوْا وَلَمْ تَنْقُصْهُمُ الدُّنْيَا وَإِنَّا أَصَبْنَا مَا لاَ نَجِدُ لَهُ مَوْضِعًا إِلاَّ التُّرَابَ وَلَوْلاَ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَانَا أَنْ نَدْعُوَ بِالْمَوْتِ لَدَعَوْتُ بِهِ، ثُمَّ أَتَيْنَاهُ مَرَّةً أُخْرَى وَهْوَ يَبْنِي حَائِطًا لَهُ فَقَالَ إِنَّ الْمُسْلِمَ لَيُوجَرُ فِي كُلِّ شَىْءٍ يُنْفِقُهُ إِلاَّ فِي شَىْءٍ يَجْعَلُهُ فِي هَذَا التُّرَابِ‏.‏\hadithno{5672}\hadithtrans{Narrated Qais bin Abi Hazim:We went to pay a visit to Khabbab (who was sick) and he had been branded (cauterized) at seven places in his body. He said, "Our companions who died (during the lifetime of the Prophet) left (this world) without having their rewards reduced through enjoying the pleasures of this life, but we have got (so much) wealth that we find no way to spend It except on the construction of buildings Had the Prophet not forbidden us to wish for death, I would have wished for it.' We visited him for the second time while he was building a wall. He said, A Muslim is rewarded (in the Hereafter) for whatever he spends except for something that he spends on building}}
\hadithdefcmd{bukhari}{5673}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو عُبَيْدٍ، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لَنْ يُدْخِلَ أَحَدًا عَمَلُهُ الْجَنَّةَ ‏"‏‏.‏ قَالُوا وَلاَ أَنْتَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ لاَ، وَلاَ أَنَا إِلاَّ أَنْ يَتَغَمَّدَنِي اللَّهُ بِفَضْلٍ وَرَحْمَةٍ فَسَدِّدُوا وَقَارِبُوا وَلاَ يَتَمَنَّيَنَّ أَحَدُكُمُ الْمَوْتَ إِمَّا مُحْسِنًا فَلَعَلَّهُ أَنْ يَزْدَادَ خَيْرًا، وَإِمَّا مُسِيئًا فَلَعَلَّهُ أَنْ يَسْتَعْتِبَ ‏"‏‏.‏\hadithno{5673}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "The good deeds of any person will not make him enter Paradise." (i.e., None can enter Paradise through his good deeds.) They (the Prophet's companions) said, 'Not even you, O Allah's Messenger (ﷺ)?' He said, "Not even myself, unless Allah bestows His favor and mercy on me." So be moderate in your religious deeds and do the deeds that are within your ability: and none of you should wish for death, for if he is a good doer, he may increase his good deeds, and if he is an evil doer, he may repent to Allah}}
\hadithdefcmd{bukhari}{5674}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، قَالَ سَمِعْتُ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم وَهْوَ مُسْتَنِدٌ إِلَىَّ يَقُولُ ‏ "‏ اللَّهُمَّ اغْفِرْ لِي وَارْحَمْنِي وَأَلْحِقْنِي بِالرَّفِيقِ الأَعْلَى ‏"‏‏.‏\hadithno{5674}\hadithtrans{Narrated `Aisha:I heard the Prophet (ﷺ) , who was resting against me, saying, "O Allah! Excuse me and bestow Your Mercy on me and let me join with the highest companions (in Paradise)." See Qur'an}}
\hadithdefcmd{bukhari}{5675}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا أَتَى مَرِيضًا ـ أَوْ أُتِيَ بِهِ ـ قَالَ ‏ "‏ أَذْهِبِ الْبَاسَ رَبَّ النَّاسِ، اشْفِ وَأَنْتَ الشَّافِي لاَ شِفَاءَ إِلاَّ شِفَاؤُكَ، شِفَاءً لاَ يُغَادِرُ سَقَمًا ‏"‏‏.‏ قَالَ عَمْرُو بْنُ أَبِي قَيْسٍ وَإِبْرَاهِيمُ بْنُ طَهْمَانَ عَنْ مَنْصُورٍ عَنْ إِبْرَاهِيمَ وَأَبِي الضُّحَى إِذَا أُتِيَ بِالْمَرِيضِ، وَقَالَ جَرِيرٌ عَنْ مَنْصُورٍ عَنْ أَبِي الضُّحَى وَحْدَهُ، وَقَالَ إِذَا أَتَى مَرِيضًا‏.‏\hadithno{5675}\hadithtrans{Narrated `Aisha:Whenever Allah's Messenger (ﷺ) paid a visit to a patient, or a patient was brought to him, he used to invoke Allah, saying, "Take away the disease, O the Lord of the people! Cure him as You are the One Who cures. There is no cure but Yours, a cure that leaves no disease}}
\hadithdefcmd{bukhari}{5676}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ دَخَلَ عَلَىَّ النَّبِيُّ صلى الله عليه وسلم وَأَنَا مَرِيضٌ فَتَوَضَّأَ فَصَبَّ عَلَىَّ أَوْ قَالَ صُبُّوا عَلَيْهِ فَعَقَلْتُ فَقُلْتُ لاَ يَرِثُنِي إِلاَّ كَلاَلَةٌ، فَكَيْفَ الْمِيرَاثُ فَنَزَلَتْ آيَةُ الْفَرَائِضِ‏.‏\hadithno{5676}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) came to me while I was ill. He performed ablution and threw the remaining water on me (or said, "Pour it on him) " When I came to my senses I said, "O Allah's Messenger (ﷺ)! I have no son or father to be my heir, so how will be my inheritance?" Then the Verse of inheritance was revealed}}
\hadithdefcmd{bukhari}{5677}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا قَالَتْ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وُعِكَ أَبُو بَكْرٍ وَبِلاَلٌ قَالَتْ فَدَخَلْتُ عَلَيْهِمَا فَقُلْتُ يَا أَبَتِ كَيْفَ تَجِدُكَ وَيَا بِلاَلُ كَيْفَ تَجِدُكَ قَالَتْ وَكَانَ أَبُو بَكْرٍ إِذَا أَخَذَتْهُ الْحُمَّى يَقُولُ كُلُّ امْرِئٍ مُصَبَّحٌ فِي أَهْلِهِ وَالْمَوْتُ أَدْنَى مِنْ شِرَاكِ نَعْلِهِ وَكَانَ بِلاَلٌ إِذَا أُقْلِعَ عَنْهُ يَرْفَعُ عَقِيرَتَهُ فَيَقُولُ أَلاَ لَيْتَ شِعْرِي هَلْ أَبِيتَنَّ لَيْلَةً بِوَادٍ وَحَوْلِي إِذْخِرٌ وَجَلِيلُ وَهَلْ أَرِدَنْ يَوْمًا مِيَاهَ مِجَنَّةٍ وَهَلْ تَبْدُوَنْ لِي شَامَةٌ وَطَفِيلُ قَالَ قَالَتْ عَائِشَةُ فَجِئْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَقَالَ ‏ "‏ اللَّهُمَّ حَبِّبْ إِلَيْنَا الْمَدِينَةَ كَحُبِّنَا مَكَّةَ أَوْ أَشَدَّ وَصَحِّحْهَا وَبَارِكْ لَنَا فِي صَاعِهَا وَمُدِّهَا وَانْقُلْ حُمَّاهَا فَاجْعَلْهَا بِالْجُحْفَةِ ‏"‏‏.‏\hadithno{5677}\hadithtrans{Narrated `Aisha:When Allah's Messenger (ﷺ) emigrated to Medina, Abu Bakr and Bilal had a fever. I entered upon them and said, "O my father! How are you? O Bilal! How are you?" Whenever Abu Bakr got the fever he used to say, "Everybody is staying alive with his people, yet death is nearer to him than his shoe laces." And when fever deserted Bilal, he would recite (two poetic verses): "Would that I could stay overnight in a valley wherein I would be surrounded by Idhkhir and Jalil (two kinds of good smelling grass). Would that one day I could drink of the water of Majinna, and would that Shama and Tafil (two mountains at Mecca) would appear to me!" I went to Allah's Messenger (ﷺ) and informed him about that. He said, "O Allah! Make us love Medina as much or more than we love Mecca, and make it healthy, and bless its Sa and its Mudd, and take away its fever and put it in Al-Juhfa." (See Hadith No)}}
